# VSGAN
VapourSynth GAN Implementation, based on ESRGAN's implementation

# Installation and Usage
[Check out the Wiki](https://gitlab.com/imPRAGMA/VSGAN/wikis), it will explain everything you may need to know.